from setuptools import setup

setup(name='bochi_distribution',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['bochi_distribution'],
      author = 'Tanya Singh-Mishra',
      zip_safe=False)
